@@ -59,7 +59,7 @@ class RubyGemTestCase < Test::Unit::TestCase
 
   def setup
     super
-    @tempdir = File.join Dir.tmpdir, "test_rubygems_#{$$}"
+    @tempdir = File.join Dir.tmpdir, "test_rubygems_#{$$}"    
     @gemhome = File.join @tempdir, "gemhome"
     @gemcache = File.join(@gemhome, "source_cache")
     @usrcache = File.join(@gemhome, ".gem", "user_cache")
@@ -75,7 +75,7 @@ class RubyGemTestCase < Test::Unit::TestCase
       Gem::RemoteFetcher.instance_variable_set :@fetcher, nil
     end
 
-    FileUtils.rm_r @tempdir
+    FileUtils.rm_rf @tempdir
     ENV['GEMCACHE'] = nil
     Gem.clear_paths
     Gem::SourceInfoCache.instance_variable_set :@cache, nil
