@@ -1,4 +1,10 @@
 #!/usr/bin/env ruby
+#--
+# Copyright 2006 by Chad Fowler, Rich Kilmer, Jim Weirich and others.
+# All rights reserved.
+# See LICENSE.txt for permissions.
+#++
+
 
 require 'rubygems'
 Gem::manage_gems
@@ -21,11 +27,11 @@ def install_session
     puts 
     exit
   end
-  require_gem 'session'
+  gem 'session'
 end
 
 begin
-  require_gem 'session'
+  require 'session'
 rescue LoadError => e
   puts
   puts "Required Gem 'Session' missing."
